==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--google--
Rozbija tekst na pojedyncze litery
Zaznacza pojedynczy obiekt</translatorcomment>
        <translation type="obsolete">Pojedynczy</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dwa: w pionie</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dwa: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Trzy: Right</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Trzy: Left</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Trzy: Above</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trzy: Below</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trzy: Pionowa</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trzy: pozioma</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cztery: Równe</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cztery: Right</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cztery: Left</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odstępy siatki &amp;lt;odstęp siatki Meta</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation type="unfinished">Cztery: Równe</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation type="unfinished">Cztery: Left</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation type="unfinished">Cztery: Right</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation type="unfinished">Pojedynczy</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation type="unfinished">Trzy: Below</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation type="unfinished">Trzy: pozioma</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation type="unfinished">Trzy: Pionowa</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation type="unfinished">Dwa: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation type="unfinished">Dwa: w pionie</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+320"/>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Siatka
Siatka
Pozycjonowanie siatki</translatorcomment>
        <translation type="unfinished">Siatka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż punkt końcowy odnośnika
Wskaż kąt końcowy lub [kąt/długość cięciwy]</translatorcomment>
        <translation type="unfinished">End</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Punt cięcia nie jest na obiekcie.
Punt cięcia nie jest na obiekcie
Punkt cięcia nie jest na obiekcie.</translatorcomment>
        <translation type="unfinished">Na obiekcie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Prostopadły</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="unfinished">Wyśrodkuj</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="unfinished">Środek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Odetnij odcinek
Wybierz pierwszy punkt linii przecinającej</translatorcomment>
        <translation type="unfinished">Przecięcie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Wskaż punkt odniesienia
Kopiuj z punktem &amp;odniesienia</translatorcomment>
        <translation type="unfinished">Odniesienie</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="unfinished">Odstępy siatki &amp;lt;odstęp siatki Meta</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="unfinished">Odstępy siatki &amp;lt;odstęp siatki Meta</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--google--
Rozbija tekst na pojedyncze litery
Zaznacza pojedynczy obiekt</translatorcomment>
        <translation type="obsolete">Pojedynczy</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dwa: w pionie</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dwa: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Trzy: Right</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Trzy: Left</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Trzy: Above</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trzy: Below</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trzy: Pionowa</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Trzy: pozioma</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cztery: Równe</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cztery: Right</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cztery: Left</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odstępy siatki &amp;lt;odstęp siatki Meta</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation type="unfinished">Cztery: Równe</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation type="unfinished">Cztery: Left</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation type="unfinished">Cztery: Right</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation type="unfinished">Pojedynczy</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation type="unfinished">Trzy: Below</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation type="unfinished">Trzy: pozioma</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation type="unfinished">Trzy: Pionowa</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation type="unfinished">Dwa: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation type="unfinished">Dwa: w pionie</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+252"/>
        <source>Dropped data not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Importing file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Importing URL: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Siatka
Siatka
Pozycjonowanie siatki</translatorcomment>
        <translation type="obsolete">Siatka</translation>
    </message>
    <message>
        <source>End</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż punkt końcowy odnośnika
Wskaż kąt końcowy lub [kąt/długość cięciwy]</translatorcomment>
        <translation type="obsolete">End</translation>
    </message>
    <message>
        <source>On Entity</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Punt cięcia nie jest na obiekcie.
Punt cięcia nie jest na obiekcie
Punkt cięcia nie jest na obiekcie.</translatorcomment>
        <translation type="obsolete">Na obiekcie</translation>
    </message>
    <message>
        <source>Perpendicular</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Prostopadły</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Intersection</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Odetnij odcinek
Wybierz pierwszy punkt linii przecinającej</translatorcomment>
        <translation type="obsolete">Przecięcie</translation>
    </message>
    <message>
        <source>Reference</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Wskaż punkt odniesienia
Kopiuj z punktem &amp;odniesienia</translatorcomment>
        <translation type="obsolete">Odniesienie</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="unfinished">Odstępy siatki &amp;lt;odstęp siatki Meta</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="unfinished">Odstępy siatki &amp;lt;odstęp siatki Meta</translation>
    </message>
</context>
</TS>
